#
# spec file for package libsecp256k1
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define soname 5
Name:           libsecp256k1
Version:        0.6.0
Release:        1.1
Summary:        Optimized C library for EC operations on curve secp256k1
License:        MIT
Group:          System/Libraries
URL:            https://github.com/bitcoin/secp256k1
Source0:        https://github.com/bitcoin-core/secp256k1/archive/refs/tags/v%{version}.tar.gz
BuildRequires:  automake
BuildRequires:  libtool
BuildRequires:  pkgconfig

%description
Optimized C library for EC operations on curve secp256k1.

%package -n %{name}-%{soname}
Summary:        Optimized C library for EC operations on curve secp256k1
Group:          System/Libraries

%description -n %{name}-%{soname}
The %{name} library is a work in progress and is being used to research best practices. Use at your own risk.

Features:
- secp256k1 ECDSA signing/verification and key generation.
- Adding/multiplying private/public keys.
- Serialization/parsing of private keys, public keys, signatures.
- Constant time, constant memory access signing and pubkey generation.
- Derandomized DSA (via RFC6979 or with a caller provided function.)
- Very efficient implementation.

%package devel
Summary:        Development files for %{name}
Group:          Development/Libraries/C and C++
Requires:       %{name}-%{soname} = %{version}

%description devel
The %{name}-devel package contains libraries and header files for developing applications that use %{name}.

%prep
%setup -q -n secp256k1-%{version}

%build
./autogen.sh
export CFLAGS_FOR_BUILD="%{optflags}"
%configure \
    --disable-static \
    --enable-module-ecdh \
    --enable-module-recovery \
    --enable-experimental
%make_build

%install
%make_install
mkdir -p %{buildroot}%{_libdir}/pkgconfig
install -m 0644 -p -t %{buildroot}%{_libdir}/pkgconfig *.pc
find %{buildroot} -type f -name "*.la" -delete -print

%check
./tests

%post -n %{name}-%{soname} -p /sbin/ldconfig
%postun -n %{name}-%{soname} -p /sbin/ldconfig

%files -n %{name}-%{soname}
%{_libdir}/*.so.*
%license COPYING

%files devel
%{_includedir}/*.h
%{_libdir}/pkgconfig/libsecp256k1.pc
%{_libdir}/*.so
%doc README.md
%license COPYING

%changelog
* Wed Nov 27 2024 Michael Vetter <mvetter@suse.com>
- Update to 0.6.0:
  * Add a musig module
  * Add a significantly more robust method to clear secrets from the stack
  * Remove the unused secp256k1_scratch_space functions
* Fri Aug  2 2024 Michael Vetter <mvetter@suse.com>
- Update to 0.5.1:
  * Added usage example for an ElligatorSwift key exchange.
  * The default size of the precomputed table for signing was changed
    from 22 KiB to 86 KiB. The size can be changed with the configure
    option --ecmult-gen-kb (SECP256K1_ECMULT_GEN_KB for CMake).
  * "auto" is no longer an accepted value for the --with-ecmult-window
    and --with-ecmult-gen-kb configure options (this also applies to
    SECP256K1_ECMULT_WINDOW_SIZE and SECP256K1_ECMULT_GEN_KB in CMake).
    To achieve the same configuration as previously provided by the
    "auto" value, omit setting the configure option explicitly.
  * Fixed compilation when the extrakeys module is disabled.
  * The ABI is backward compatible with versions 0.5.0, 0.4.x and 0.3.x.
* Tue May  7 2024 Michael Vetter <mvetter@suse.com>
- Update to 0.5.0:
  Added:
  * New function secp256k1_ec_pubkey_sort that sorts public keys
    using lexicographic (of compressed serialization) order.
  Changed:
  * The implementation of the point multiplication algorithm used
    for signing and public key generation was changed, resulting
    in improved performance for those operations. The related
    configure option --ecmult-gen-precision was replaced with
  - -ecmult-gen-kb (ECMULT_GEN_KB for CMake).
    This changes the supported precomputed table sizes for these
    operations. The new supported sizes are 2 KiB, 22 KiB, or 86
    KiB (while the old supported sizes were 32 KiB, 64 KiB, or 512 KiB).
  ABI Compatibility:
  * The ABI is backward compatible with versions 0.4.x and 0.3.x.
* Fri Dec 22 2023 Michael Vetter <mvetter@suse.com>
- Update to 0.4.1:
  * The point multiplication algorithm used for ECDH operations
    (module ecdh) was replaced with a slightly faster one.
  * Optional handwritten x86_64 assembly for field operations was
    removed because modern C compilers are able to output more efficient
    assembly. This change results in a significant speedup of some
    library functions when handwritten x86_64 assembly is enabled
    (--with-asm=x86_64 in GNU Autotools, -DSECP256K1_ASM=x86_64 in CMake),
    which is the default on x86_64. Benchmarks with GCC 10.5.0 show a
    10%% speedup for secp256k1_ecdsa_verify and secp256k1_schnorrsig_verify.
* Thu Dec  7 2023 Michael Vetter <mvetter@suse.com>
- Update to 0.4.0:
  Added:
  * New module ellswift implements ElligatorSwift encoding for public
    keys and x-only Diffie-Hellman key exchange for them. ElligatorSwift
    permits representing secp256k1 public keys as 64-byte arrays which
    cannot be distinguished from uniformly random. See:
    + Header file include/secp256k1_ellswift.h which defines the new API.
    + Document doc/ellswift.md which explains the mathematical background
    of the scheme.
    + The paper on which the scheme is based.
  * We now test the library with unreleased development snapshots of GCC
    and Clang. This gives us an early chance to catch miscompilations and
    constant-time issues introduced by the compiler (such as those that
    led to the previous two releases).
  Fixed:
  * Fixed symbol visibility in Windows DLL builds, where three internal
    library symbols were wrongly exported.
  Changed:
  * When consuming libsecp256k1 as a static library on Windows, the user
    must now define the SECP256K1_STATIC macro before including secp256k1.h.
  ABI Compatibility:
  * This release is backward compatible with the ABI of 0.3.0, 0.3.1,
    and 0.3.2. Symbol visibility is now believed to be handled properly
    on supported platforms and is now considered to be part of the ABI.
- Drop Export_SHA256_functions.patch
- Drop _service file: no need with regular versioned releases
* Sun Jul 10 2022 Mark Stopka <mstopka@opensuse.org>
- Remove TODO file from %%doc
* Sun Jul 10 2022 Mark Stopka <mstopka@opensuse.org>
- Bumped to the commit ac83be33d0956faf6b7f61a60ab524ef7d6a473a,
  used by cardano-node
* Sun Aug  2 2020 Michał Rostecki <mrostecki@suse.com>
- Bumped to the commit dbd41db16a0e91b2566820898a3ab2d7dad4fe00,
  used by Electrum 4.0.2.
* Wed Feb 13 2019 Adam Mizerski <adam@mizerski.pl>
- spec file cleanup
- added patch Export_SHA256_functions.patch
* Tue Feb  5 2019 marec@detebe.org
- bumped to latest commit
* Mon Nov 26 2018 marec@detebe.org
- bumped to latest commit
* Wed Nov  7 2018 marec@detebe.org
- bumped to latest commit
* Thu Oct 25 2018 marec@detebe.org
- bumped to latest commit
* Thu May 31 2018 marec@detebe.org
- bumped to latest commit
* Sun Apr  8 2018 marec@detebe.org
- bumped to latest commit
* Tue Mar 27 2018 marec@detebe.org
- bumped to latest commit
* Tue Feb 20 2018 adam@mizerski.pl
- build with option --enable-module-recovery
  It's disabled by default, but required by secp256k1-py
* Wed Feb  7 2018 marec@detebe.org
- bumped to latest commit
* Fri Dec 22 2017 marec@detebe.org
- bumped to latest commit
* Wed Dec 20 2017 marec@detebe.org
- bumped to latest commit
* Sat Dec  9 2017 marec@detebe.org
- bumped to latest commit
* Sat Nov 25 2017 marec@detebe.org
- bumped to latest commit
* Mon Jun 15 2015 marec@detebe.org
- reverted to latest stable version
* Sat Jun 13 2015 marec@detebe.org
- bumped to latest commit
* Sat May 30 2015 marec@detebe.org
- bumped again to latest commit
* Sat May  9 2015 marec@detebe.org
- reverted to latest compatible version
* Fri May  1 2015 marec@detebe.org
- bumped to latest commit
* Wed Apr 22 2015 marec@detebe.org
- bumped to latest commit
* Mon Apr 20 2015 marec@detebe.org
- bumped to latest commit
* Tue Apr 14 2015 marec@detebe.org
- bumped to latest commit
* Sun Apr 12 2015 marec@detebe.org
- bumped to latest commit
* Sat Apr 11 2015 marec@detebe.org
- bumped to latest commit
* Fri Apr 10 2015 marec@detebe.org
- bumped to latest commit
* Mon Mar 30 2015 marec@detebe.org
- bumped to latest commit
* Sat Mar 28 2015 marec@detebe.org
- bumped to latest commit
* Mon Mar 16 2015 marec@detebe.org
- bumped to latest commit
* Mon Mar  2 2015 marec@detebe.org
- bumped to latest commit
* Wed Feb 25 2015 marec@detebe.org
- bumped to latest commit
* Tue Feb 17 2015 marec@detebe.org
- bumped to latest commit
* Fri Feb 13 2015 marec@detebe.org
- bumped to latest commit
* Tue Feb 10 2015 marec@detebe.org
- initial package build
